/* Demonstration of Hauppauge Remote Control */
/* Roger Hardiman */
/* February 1999 */
/* This example code remains the copyright of Roger Hardiman */
/* You are free to use portions of this code in your own programs */
/* but must acknowledge the author, Roger Hardiman */

#include <stdio.h>
#include <unistd.h>
#include <sys/fcntl.h>
#include "/sys/i386/include/ioctl_meteor.h"
#include "/sys/i386/include/ioctl_bt848.h"

/* Defines for each key on the Remote Control */
#define REMOTE_0           0
#define REMOTE_1           4
#define REMOTE_2           8
#define REMOTE_3           12
#define REMOTE_4           16
#define REMOTE_5           20
#define REMOTE_6           24
#define REMOTE_7           28
#define REMOTE_8           32
#define REMOTE_9           36
#define REMOTE_RADIO       48
#define REMOTE_MUTE        52
#define REMOTE_TV          60
#define REMOTE_VOL_PLUS    64
#define REMOTE_VOL_MINUS   68
#define REMOTE_RESERVED    120
#define REMOTE_CHAN_PLUS   128
#define REMOTE_CHAN_MINUS  132
#define REMOTE_SOURCE      136
#define REMOTE_MINIMIZE    152
#define REMOTE_FULL_SCREEN 184

/* Map the key pressed on the remote to an ASCII string */
char * keyname(unsigned char v){
  switch (v) {
    case REMOTE_0:		return "0";
    case REMOTE_1:		return "1";
    case REMOTE_2:		return "2";
    case REMOTE_3:		return "3";
    case REMOTE_4:		return "4";
    case REMOTE_5:		return "5";
    case REMOTE_6:		return "6";
    case REMOTE_7:		return "7";
    case REMOTE_8:		return "8";
    case REMOTE_9:		return "9";
    case REMOTE_RADIO:		return "Radio";
    case REMOTE_MUTE:		return "Mute";
    case REMOTE_TV:		return "TV";
    case REMOTE_VOL_PLUS:	return "Vol +";
    case REMOTE_VOL_MINUS:	return "Vol -";
    case REMOTE_RESERVED:	return "Reserved";
    case REMOTE_CHAN_PLUS:	return "Chan +";
    case REMOTE_CHAN_MINUS:	return "Chan -";
    case REMOTE_SOURCE:		return "Source";
    case REMOTE_MINIMIZE:	return "Minimize";
    case REMOTE_FULL_SCREEN:	return "Full Screen";
    default:    printf("Error, invalid key %d",v);
                return "";
  }
}
void main(void) {

 int t; /* tuner device */
 int times_per_second = 20; /* Frequency at which we poll the remote control */
 /* open tuner device */
 t = open("/dev/tuner0", O_RDONLY);
 if (t < 0) {
	printf("cannot open tuner\n");
	exit(1);
 }

 printf("tuner open\n");

 /* try and read the Remote Control Data */
 {
 unsigned char b1, b2, b3;
 unsigned char address=0x35; /*i2c location for read */
 unsigned char last_valid_b1 = 0;
 struct bktr_remote remote;
 for(;;){
   /* Read the raw data from the remote control */
   ioctl(t, REMOTE_GETKEY, &remote);

   b1 = remote.data[0];
   b2 = remote.data[1];
   b3 = remote.data[2];
   //printf("%d %d %d\n",b1,b2,b3);
   /* only sequences starting 192 and 224 are valid. 000 and 255 are invalid */
   if ((b1 == 224) || (b1 == 192)) {
     /* most keys do not have auto repeat except the volume */
     if ((b2 == REMOTE_VOL_PLUS) || (b2 == REMOTE_VOL_MINUS)) {
                                     printf("%s\n",keyname(b2));
                                     last_valid_b1 = 0; }
     /* if the toggle code has changed, this is a new keypress */
     else if (b1 != last_valid_b1) { printf("key %s\n",keyname(b2));
                                     last_valid_b1 = b1; }
   }
   /* sleep until it is time to poll again */
   usleep(1000000 / (float) times_per_second);
 } /* end for */
 }
}
